@@ -1,16 +1,15 @@
-/* Copyright (c) 2012, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2012, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -382,6 +381,22 @@ static int task_queue_full(task_queue *q) { return q->curn >= MAXTASKS; }
 
 #endif
 
+unsigned long long int get_time_since_the_epoch() {
+#ifdef _WIN32
+  return std::chrono::duration_cast<std::chrono::microseconds>(
+             std::chrono::system_clock::now().time_since_epoch())
+      .count();
+#else
+  struct timeval t;
+  /*
+  The following loop is here because gettimeofday may fail on some systems
+  */
+  while (gettimeofday(&t, nullptr) != 0) {
+  }
+  return (static_cast<unsigned long long int>(t.tv_sec) * 1000000 + t.tv_usec);
+#endif /* _WIN32 */
+}
+
 #define FIX_POS(i) q->x[i]->heap_pos = (i)
 /* #define TASK_SWAP(x,y) { task_env *tmp = (x); (x) = (y); (y) = (tmp); } */
 #define TASK_SWAP(i, j)      \
@@ -971,6 +986,7 @@ int task_read(connection_descriptor const *con, void *buf, int n, int64_t *ret,
   FINALLY
   receive_count++;
   if (*ret > 0) receive_bytes += (uint64_t)(*ret);
+  cfg_app_get_storage_statistics()->add_bytes_received(*ret);
   TASK_END;
 }
 
@@ -1074,6 +1090,7 @@ int task_write(connection_descriptor const *con, void *_buf, uint32_t n,
   FINALLY
   send_count++;
   send_bytes += ep->total;
+  cfg_app_get_storage_statistics()->add_bytes_sent(ep->total);
   TASK_END;
 }
 
