@@ -1,19 +1,18 @@
 #ifndef ITEM_SUBSELECT_INCLUDED
 #define ITEM_SUBSELECT_INCLUDED
 
-/* Copyright (c) 2002, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2002, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -24,7 +23,8 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */
 
-/* subselect Item */
+/// Implements classes that represent subqueries and predicates containing
+/// table subqueries.
 
 #include <assert.h>
 #include <sys/types.h>
@@ -64,7 +64,6 @@ class Query_result_union;
 class Query_block;
 class Query_expression;
 class String;
-class SubqueryWithResult;
 class THD;
 class Temp_table_param;
 class my_decimal;
@@ -75,43 +74,19 @@ class Table_ref;
 template <class T>
 class List;
 
-/* base class for subselects */
+/// Base class that is common to all subqueries and subquery predicates
 
 class Item_subselect : public Item_result_field {
   typedef Item_result_field super;
 
- private:
-  bool value_assigned; /* value already assigned to subselect */
-  /**
-      Whether or not execution of this subselect has been traced by
-      optimizer tracing already. If optimizer trace option
-      REPEATED_SUBSELECT is disabled, this is used to disable tracing
-      after the first one.
-  */
-  bool traced_before;
-
  public:
-  /*
-    Used inside Item_subselect::fix_fields() according to this scenario:
-      > Item_subselect::fix_fields
-        > subquery->prepare
-          > query_block->prepare
-            (Here we realize we need to do the rewrite and set
-             substitution= some new Item, eg. Item_in_optimizer )
-          < query_block->prepare
-        < subquery->prepare
-        *ref= substitution;
-      < Item_subselect::fix_fields
-  */
-  Item *substitution;
+  Query_expression *query_expr() const { return m_query_expr; }
 
-  /* unit of subquery */
-  Query_expression *unit;
   /**
      If !=NO_PLAN_IDX: this Item is in the condition attached to the JOIN_TAB
      having this index in the parent JOIN.
   */
-  int in_cond_of_tab;
+  int in_cond_of_tab{NO_PLAN_IDX};
 
   // For EXPLAIN.
   enum enum_engine_type { OTHER_ENGINE, INDEXSUBQUERY_ENGINE, HASH_SJ_ENGINE };
@@ -125,82 +100,46 @@ class Item_subselect : public Item_result_field {
   void create_iterators(THD *thd);
   virtual AccessPath *root_access_path() const { return nullptr; }
 
- protected:
-  /**
-    We need this method, because some compilers do not allow 'this'
-    pointer in constructor initialization list, but we need to pass a pointer
-    to subselect Item class to Query_result_interceptor's constructor.
-  */
-  void init(Query_block *select, Query_result_subquery *result);
-
-  /// The inner part of the subquery.
-  unique_ptr_destroy_only<SubqueryWithResult> subquery;
-
-  /// Only relevant for Item_in_subselect; optimized structure used for
-  /// execution in place of running the entire subquery.
-  subselect_indexsubquery_engine *indexsubquery_engine = nullptr;
-
-  /// cache of used tables
-  table_map used_tables_cache;
-  /// allowed number of columns (1 for scalar subqueries)
-  uint max_columns;
-  /// where subquery is placed
-  enum_parsing_context parsing_place;
-  /// work with 'substitution'
-  bool have_to_be_excluded;
-
- public:
-  /// cache of used tables, used to identify tables added for IN subquery
-  table_map m_subquery_used_tables{0};
-  /// subquery is transformed
-  bool changed;
-
-  enum subs_type {
-    UNKNOWN_SUBS,
-    SINGLEROW_SUBS,
-    EXISTS_SUBS,
-    IN_SUBS,
-    ALL_SUBS,
-    ANY_SUBS
+  enum Subquery_type {
+    SCALAR_SUBQUERY,  ///< Scalar or row subquery
+    EXISTS_SUBQUERY,  ///< [NOT] EXISTS subquery predicate
+    IN_SUBQUERY,      ///< [NOT] IN subquery predicate
+    ALL_SUBQUERY,     ///< comp-op ALL quantified comparison predicate
+    ANY_SUBQUERY      ///< comp-op ANY quantified comparison predicate
   };
 
-  Item_subselect();
-  explicit Item_subselect(const POS &pos);
-
- private:
-  /// Accumulate properties from underlying query expression
-  void accumulate_properties();
-  /// Accumulate properties from underlying query block
-  void accumulate_properties(Query_block *select);
-  /// Accumulate properties from a selected expression within a query block.
-  void accumulate_expression(Item *item);
-  /// Accumulate properties from a condition or GROUP/ORDER within a query
-  /// block.
-  void accumulate_condition(Item *item);
-
- public:
   /// Accumulate used tables
   void accumulate_used_tables(table_map add_tables) {
-    used_tables_cache |= add_tables;
+    m_used_tables_cache |= add_tables;
     m_subquery_used_tables |= add_tables;
   }
 
-  virtual subs_type substype() const { return UNKNOWN_SUBS; }
+  virtual Subquery_type subquery_type() const = 0;
 
   void cleanup() override;
-  virtual void reset() { null_value = true; }
-  virtual bool select_transformer(THD *thd, Query_block *select) = 0;
-  bool assigned() const { return value_assigned; }
-  void assigned(bool a) { value_assigned = a; }
+  /**
+    Reset state after a single execution of a subquery, useful when a
+    dependent subquery must be evaluated multiple times for varying values
+    of the outer references.
+    This is a lighter cleanup procedure than the one provided by cleanup().
+  */
+  virtual void reset() {
+    m_value_assigned = false;
+    null_value = true;
+  }
+  bool is_value_assigned() const { return m_value_assigned; }
+  void set_value_assigned() { m_value_assigned = true; }
+  void reset_value_assigned() { m_value_assigned = false; }
   enum Type type() const override;
   bool is_null() override { return update_null_value() || null_value; }
   bool fix_fields(THD *thd, Item **ref) override;
   void fix_after_pullout(Query_block *parent_query_block,
                          Query_block *removed_query_block) override;
   virtual bool exec(THD *thd);
-  bool resolve_type(THD *) override;
-  table_map used_tables() const override { return used_tables_cache; }
+  table_map used_tables() const override { return m_used_tables_cache; }
   table_map not_null_tables() const override { return 0; }
+  /// @returns used tables for subquery (excluding any left-hand expression)
+  table_map subquery_used_tables() const { return m_subquery_used_tables; }
   Item *get_tmp_table_item(THD *thd) override;
   void update_used_tables() override;
   void print(const THD *thd, String *str,
@@ -217,12 +156,17 @@ class Item_subselect : public Item_result_field {
   bool is_evaluated() const;
   bool is_uncacheable() const;
 
-  /*
+  /**
     Used by max/min subquery to initialize value presence registration
-    mechanism. Engine call this method before rexecution query.
+    mechanism. Engine calls this function before re-execution of subquery.
   */
-  virtual void reset_value_registration() {}
-  enum_parsing_context place() { return parsing_place; }
+  virtual void reset_has_values() {}
+  /**
+    @returns the "place" where this subquery is located in the simply
+             containing query block.
+  */
+  enum_parsing_context place() { return m_parsing_place; }
+
   bool walk(Item_processor processor, enum_walk walk, uchar *arg) override;
   bool explain_subquery_checker(uchar **arg) override;
   bool inform_item_in_cond_of_tab(uchar *arg) override;
@@ -230,7 +174,7 @@ class Item_subselect : public Item_result_field {
 
   const char *func_name() const override {
     assert(0);
-    return "subselect";
+    return "subquery";
   }
 
   bool check_function_as_value_generator(uchar *args) override {
@@ -248,7 +192,7 @@ class Item_subselect : public Item_result_field {
     Collect_subq_info(Query_block *owner) : m_query_block(owner) {}
     bool contains(Query_expression *candidate) {
       for (auto sq : list) {
-        if (sq->unit == candidate) return true;
+        if (sq->m_query_expr == candidate) return true;
       }
       return false;
     }
@@ -257,39 +201,77 @@ class Item_subselect : public Item_result_field {
   bool collect_subqueries(uchar *) override;
   Item *replace_item_field(uchar *arg) override;
   Item *replace_item_view_ref(uchar *arg) override;
-  Item *replace_item(Item_transformer t, uchar *arg);
 
-  friend class Query_result_interceptor;
-  friend class Item_in_optimizer;
-  friend bool Item_field::fix_fields(THD *, Item **);
-  friend int Item_field::fix_outer_field(THD *, Field **, Item **);
-  friend bool Item_ref::fix_fields(THD *, Item **);
-  friend void Item_ident::fix_after_pullout(Query_block *parent_query_block,
-                                            Query_block *removed_query_block);
+ protected:
+  Item_subselect() : Item_result_field() { set_subquery(); }
+  explicit Item_subselect(const POS &pos) : super(pos) { set_subquery(); }
+  /**
+    Bind this subquery object with the supplied query expression.
+    As part of transformations, this function may re-bind the subquery to
+    a different query expression.
+
+    @param qe  supplied query expression
+  */
+  void bind(Query_expression *qe);
+
+  /// The query expression of the subquery
+  Query_expression *m_query_expr{nullptr};  // Actual value set in construction
+
+  /// The query result object associated with the query expression
+  Query_result_interceptor *m_query_result{nullptr};
+
+  /// Only relevant for Item_in_subselect; optimized structure used for
+  /// execution in place of running the entire subquery.
+  subselect_indexsubquery_engine *indexsubquery_engine{nullptr};
+
+  /// cache of used tables
+  table_map m_used_tables_cache{0};
+  /// cache of used tables from subquery only (not including LHS of IN subquery)
+  table_map m_subquery_used_tables{0};
+
+  /// allowed number of columns (1 for scalar subqueries)
+  uint m_max_columns{0};  // Irrelevant value, actually set during construction
+  /// where subquery is placed
+  enum_parsing_context m_parsing_place{CTX_NONE};
 
  private:
   bool subq_opt_away_processor(uchar *arg) override;
 
- protected:
-  uint unit_cols() const;
+  /// Accumulate properties from underlying query expression
+  void accumulate_properties();
+  /// Accumulate properties from underlying query block
+  void accumulate_properties(Query_block *select);
+  /// Accumulate properties from a selected expression within a query block.
+  void accumulate_expression(Item *item);
+  /// Accumulate properties from a condition or GROUP/ORDER within a query
+  /// block.
+  void accumulate_condition(Item *item);
+
+  /// True if value has been assigned to subquery
+  bool m_value_assigned{false};
+  /**
+    Whether or not execution of this subquery has been traced by
+    optimizer tracing already. If optimizer trace option
+    REPEATED_SUBSELECT is disabled, this is used to disable tracing
+    after the first one.
+  */
+  bool m_traced_before{false};
 };
 
-/* single value subselect */
+/// Class that represents scalar subquery and row subquery
 
 class Item_singlerow_subselect : public Item_subselect {
- protected:
-  Item_cache *value, **row;
-  bool no_rows;  ///< @c no_rows_in_result
  public:
   Item_singlerow_subselect(Query_block *query_block);
-  Item_singlerow_subselect()
-      : Item_subselect(), value(nullptr), row(nullptr), no_rows(false) {}
+  Item_singlerow_subselect() : Item_subselect() {}
 
+  bool fix_fields(THD *thd, Item **ref) override;
   void cleanup() override;
-  subs_type substype() const override { return SINGLEROW_SUBS; }
+  Subquery_type subquery_type() const override { return SCALAR_SUBQUERY; }
+  bool create_row(const mem_root_deque<Item *> &item_list, Item_cache **row,
+                  bool possibly_empty);
 
   void reset() override;
-  bool select_transformer(THD *thd, Query_block *select) override;
   void store(uint i, Item *item);
   double val_real() override;
   longlong val_int() override;
@@ -309,18 +291,16 @@ class Item_singlerow_subselect : public Item_subselect {
   */
   void no_rows_in_result() override;
 
-  uint cols() const override { return unit_cols(); }
+  uint cols() const override;
 
   /**
     @note that this returns the i-th element of the SELECT list.
-    To check for nullability, look at this->maybe_null and not
-    element_index[i]->maybe_null, since the selected expressions are
+    To check for nullability, look at this->is_nullable() and not
+    element_index[i]->is_nullable(), since the selected expressions are
     always NULL if the subquery is empty.
   */
-  Item *element_index(uint i) override {
-    return reinterpret_cast<Item *>(row[i]);
-  }
-  Item **addr(uint i) override { return (Item **)row + i; }
+  Item *element_index(uint i) override { return m_row[i]; }
+  Item **addr(uint i) override { return pointer_cast<Item **>(m_row) + i; }
   bool check_cols(uint c) override;
   bool null_inside() override;
   void bring_value() override;
@@ -365,26 +345,47 @@ class Item_singlerow_subselect : public Item_subselect {
   std::optional<ContainedSubquery> get_contained_subquery(
       const Query_block *outer_query_block) override;
   friend class Query_result_scalar_subquery;
+
+ private:
+  /// Value cache of a scalar subquery
+  Item_cache *m_value{nullptr};
+  /**
+    Value cache for a row or scalar subquery. In case of a scalar subquery,
+    m_row points directly at m_value. In case of a row subquery, m_row
+    is an array of pointers to individual Item_cache objects.
+  */
+  Item_cache **m_row{nullptr};
+  bool m_no_rows{false};  ///< @c no_rows_in_result
 };
 
 /* used in static ALL/ANY optimization */
 class Item_maxmin_subselect final : public Item_singlerow_subselect {
- protected:
-  bool max;
-  bool was_values;  // Set if we have found at least one row
  public:
+  /**
+    Create an Item for use in transformation of quantified comparison
+    predicates that can be evaluated using MAX or MIN aggregation.
+
+    @param parent      The quantified comparison predicate that is transformed.
+    @param query_block The query block representing the inner part of the subq.
+    @param max_arg     Whether the aggregation is for MAX or MIN.
+  */
   Item_maxmin_subselect(Item_subselect *parent, Query_block *query_block,
-                        bool max, bool ignore_nulls);
+                        bool max_arg);
   void print(const THD *thd, String *str,
              enum_query_type query_type) const override;
   void cleanup() override;
-  bool any_value() { return was_values; }
-  void register_value() { was_values = true; }
-  void reset_value_registration() override { was_values = false; }
+  bool has_values() const { return m_has_values; }
+  void register_value() { m_has_values = true; }
+  void reset_has_values() override { m_has_values = false; }
   bool is_maxmin() const override { return true; }
+
+ private:
+  bool m_max;                ///< True if performing MAX, false if MIN
+  bool m_has_values{false};  ///< Set if we have found at least one row
 };
 
-/* exists subselect */
+/// Classes that represent predicates over table subqueries:
+/// [NOT] EXISTS, [NOT] IN, ANY/SOME and ALL
 
 /**
   Strategy which will be used to handle this subquery: flattening to a
@@ -417,11 +418,23 @@ enum class Subquery_strategy : int {
 class Item_exists_subselect : public Item_subselect {
   typedef Item_subselect super;
 
- protected:
-  /// value of this item (boolean: exists/not-exists)
-  bool value{false};
-
  public:
+  /**
+    Create an Item that represents an EXISTS subquery predicate, or any
+    quantified comparison predicate that uses the same base class.
+
+    @param query_block First query block of query expression representing
+                       the contained subquery.
+  */
+  explicit Item_exists_subselect(Query_block *query_block);
+
+  Item_exists_subselect() : Item_subselect() {}
+
+  explicit Item_exists_subselect(const POS &pos) : super(pos) {}
+
+  // The left-hand expression of the subquery predicate. Unused with EXISTS
+  Item *left_expr{nullptr};
+
   /// Priority of this predicate in the convert-to-semi-join-nest process.
   int sj_convert_priority{0};
   /// Execution strategy chosen for this Item
@@ -446,21 +459,29 @@ class Item_exists_subselect : public Item_subselect {
   */
   Table_ref *embedding_join_nest{nullptr};
 
-  Item_exists_subselect(Query_block *select);
-
-  Item_exists_subselect() : Item_subselect() {}
-
-  explicit Item_exists_subselect(const POS &pos) : super(pos) {}
-
   void notify_removal() override { strategy = Subquery_strategy::DELETED; }
 
-  bool select_transformer(THD *, Query_block *) override {
-    strategy = Subquery_strategy::SUBQ_EXISTS;
-    return false;
-  }
-  subs_type substype() const override { return EXISTS_SUBS; }
+  /*
+    Transform subquery predicate to a form that can be executed, e.g.
+    as an EXISTS subquery, or a MAX or MIN aggregation on the subquery.
+
+    This is a virtual function that has implementations for EXISTS, IN
+    and quantified comparison subquery predicates.
+
+    @param thd              Thread handle
+    @param[out] transformed Points to transformed representation of the object
+                            if unchanged: No transformation was performed
+
+    @returns false if success, true if error
+  */
+  virtual bool transformer(THD *thd, Item **transformed);
+
+  Subquery_type subquery_type() const override { return EXISTS_SUBQUERY; }
   bool is_bool_func() const override { return true; }
-  void reset() override { value = false; }
+  void reset() override {
+    reset_value_assigned();
+    m_value = false;
+  }
 
   enum Item_result result_type() const override { return INT_RESULT; }
   /*
@@ -484,7 +505,7 @@ class Item_exists_subselect : public Item_subselect {
   Item *truth_transformer(THD *, enum Bool_test test) override;
   bool translate(bool &null_v, bool v);
   void apply_is_true() override {
-    bool had_is = with_is_op();
+    const bool had_is = with_is_op();
     truth_transformer(nullptr, BOOL_IS_TRUE);
     if (!had_is && value_transform == BOOL_IS_TRUE)
       implicit_is_op = true;  // needn't be written by EXPLAIN
@@ -492,6 +513,7 @@ class Item_exists_subselect : public Item_subselect {
   /// True if the Item has decided that it can do antijoin
   bool can_do_aj = false;
   bool choose_semijoin_or_antijoin();
+  bool fix_fields(THD *thd, Item **ref) override;
   longlong val_int() override;
   double val_real() override;
   String *val_str(String *) override;
@@ -506,6 +528,20 @@ class Item_exists_subselect : public Item_subselect {
              enum_query_type query_type) const override;
 
   friend class Query_result_exists_subquery;
+
+ protected:
+  bool is_semijoin_candidate(THD *thd);
+  bool is_derived_candidate(THD *thd);
+
+  /// value of this item (boolean: exists/not-exists)
+  bool m_value{false};
+
+  /**
+    True if naked IN is allowed to exchange FALSE for UNKNOWN.
+    Because this is about the naked IN, there is no public ignore_unknown(),
+    intentionally, so that callers don't get it wrong.
+  */
+  bool abort_on_null{false};
 };
 
 /**
@@ -516,7 +552,7 @@ class Item_exists_subselect : public Item_subselect {
   This class has:
    - A "subquery execution engine" (as a subclass of Item_subselect) that allows
      it to evaluate subqueries. (and this class participates in execution by
-     having was_null variable where part of execution result is stored.
+     having m_was_null variable where part of execution result is stored.
    - Transformation methods (todo: more on this).
 
   This class is not used directly, it is "wrapped" into Item_in_optimizer
@@ -527,20 +563,111 @@ class Item_in_subselect : public Item_exists_subselect {
   typedef Item_exists_subselect super;
 
  public:
-  Item *left_expr;
+  Item_in_subselect(Item *left_expr, Query_block *query_block);
+  Item_in_subselect(const POS &pos, Item *left_expr,
+                    PT_subquery *pt_subquery_arg);
+
+  Item_in_subselect() : Item_exists_subselect(), pt_subselect(nullptr) {}
+
+  bool do_itemize(Parse_context *pc, Item **res) override;
+
+  void cleanup() override;
+  Subquery_type subquery_type() const override { return IN_SUBQUERY; }
+
+  void reset() override {
+    m_value = false;
+    null_value = false;
+    m_was_null = false;
+  }
+  bool transformer(THD *thd, Item **transformed) override;
+  bool quantified_comp_transformer(THD *thd, Comp_creator *func,
+                                   Item **transformed);
+  bool single_value_transformer(THD *thd, Comp_creator *func,
+                                Item **transformed);
+  bool row_value_transformer(THD *thd, Item **transformed);
+  bool single_value_in_to_exists_transformer(THD *thd, Query_block *select,
+                                             Comp_creator *func);
+  bool row_value_in_to_exists_transformer(THD *thd, Query_block *select,
+                                          Item_in_optimizer *optimizer);
+  bool subquery_allows_materialization(THD *thd, Query_block *query_block,
+                                       const Query_block *outer);
+  bool walk(Item_processor processor, enum_walk walk, uchar *arg) override;
+  Item *transform(Item_transformer transformer, uchar *arg) override;
+  Item *compile(Item_analyzer analyzer, uchar **arg_p,
+                Item_transformer transformer, uchar *arg_t) override;
+
+  bool exec(THD *thd) override;
+  longlong val_int() override;
+  double val_real() override;
+  String *val_str(String *) override;
+  my_decimal *val_decimal(my_decimal *) override;
+  bool val_bool() override;
+  bool test_limit();
+  void print(const THD *thd, String *str,
+             enum_query_type query_type) const override;
+  void fix_after_pullout(Query_block *parent_query_block,
+                         Query_block *removed_query_block) override;
+  void update_used_tables() override;
+  bool init_left_expr_cache(THD *thd);
+
+  /**
+     Once the decision to use IN->EXISTS has been taken, performs some last
+     steps of this transformation.
+  */
+  bool finalize_exists_transform(THD *thd, Query_block *select);
+  /**
+     Once the decision to use materialization has been taken, performs some
+     last steps of this transformation.
+  */
+  bool finalize_materialization_transform(THD *thd, JOIN *join);
+  AccessPath *root_access_path() const override;
+  std::optional<ContainedSubquery> get_contained_subquery(
+      const Query_block *outer_query_block) override;
+
+  bool in2exists_added_to_where() const {
+    return m_in2exists_info != nullptr && m_in2exists_info->added_to_where;
+  }
+
+  /// Is reliable only if IN->EXISTS has been done.
+  bool dependent_before_in2exists() const {
+    return m_in2exists_info->dependent_before;
+  }
+
+  bool *get_cond_guard(int i) const {
+    return m_pushed_cond_guards != nullptr ? m_pushed_cond_guards + i : nullptr;
+  }
+  void set_cond_guard_var(int i, bool v) const {
+    if (m_pushed_cond_guards != nullptr) m_pushed_cond_guards[i] = v;
+  }
+
+  friend class Item_ref_null_helper;
+  friend class Item_is_not_null_test;
+  friend class Item_in_optimizer;
+  friend class subselect_indexsubquery_engine;
+  friend class subselect_hash_sj_engine;
+
+  /// Used to trigger on/off conditions that were pushed down to subquery
+  bool *m_pushed_cond_guards{nullptr};
+
+  /// Point on NOT/NOP before ALL/SOME subquery
+  Item_func_not_all *m_upper_item{nullptr};
 
  protected:
   /**
     Cache of the left operand of the subquery predicate. Allocated in the
     runtime memory root, for each execution, thus need not be freed.
   */
-  List<Cached_item> *left_expr_cache;
-  bool left_expr_cache_filled;  ///< Whether left_expr_cache holds a value
-  /** The need for expr cache may be optimized away, @sa init_left_expr_cache.
-   */
-  bool need_expr_cache;
+  List<Cached_item> *m_left_expr_cache{nullptr};
+
+  /// Whether m_left_expr_cache holds a value
+  bool m_left_expr_cache_filled{false};
+
+  /// The need for expr cache may be optimized away, @sa init_left_expr_cache.
+  bool need_expr_cache{true};
 
  private:
+  bool mark_as_outer(Item *left_row, size_t col);
+
   /**
     In the case of
 
@@ -559,24 +686,10 @@ class Item_in_subselect : public Item_exists_subselect {
     This will refer to a cached value which is reevaluated once for each
     candidate row, cf. setup in #single_value_transformer.
   */
-  Item_ref *m_injected_left_expr;
+  Item_ref *m_injected_left_expr{nullptr};
 
-  /**
-    Pointer to the created Item_in_optimizer; it is stored for the same
-    reasons as 'm_injected_left_expr'.
-  */
-  Item_in_optimizer *optimizer;
-  bool was_null;
+  bool m_was_null{false};
 
- protected:
-  /**
-     True if naked IN is allowed to exchange FALSE for UNKNOWN.
-     Because this is about the naked IN, there is no public ignore_unknown(),
-     intentionally, so that callers don't get it wrong.
-  */
-  bool abort_on_null;
-
- private:
   /**
      This bundles several pieces of information useful when doing the
      IN->EXISTS transform. If this transform has not been done, pointer is
@@ -598,195 +711,37 @@ class Item_in_subselect : public Item_exists_subselect {
        was done.
     */
     bool dependent_after;
-  } * in2exists_info;
+  } * m_in2exists_info{nullptr};
 
-  bool mark_as_outer(Item *left_row, size_t col);
-
- public:
-  /* Used to trigger on/off conditions that were pushed down to subselect */
-  bool *pushed_cond_guards;
-
-  Item_func_not_all *upper_item;  // point on NOT/NOP before ALL/SOME subquery
-
- private:
   PT_subquery *pt_subselect;
 
- public:
-  bool in2exists_added_to_where() const {
-    return in2exists_info && in2exists_info->added_to_where;
-  }
-
-  /// Is reliable only if IN->EXISTS has been done.
-  bool dependent_before_in2exists() const {
-    return in2exists_info->dependent_before;
-  }
-
-  bool *get_cond_guard(int i) {
-    return pushed_cond_guards ? pushed_cond_guards + i : nullptr;
-  }
-  void set_cond_guard_var(int i, bool v) {
-    if (pushed_cond_guards) pushed_cond_guards[i] = v;
-  }
-
-  Item_in_subselect(Item *left_expr, Query_block *query_block);
-  Item_in_subselect(const POS &pos, Item *left_expr,
-                    PT_subquery *pt_subquery_arg);
-
-  Item_in_subselect()
-      : Item_exists_subselect(),
-        left_expr(nullptr),
-        left_expr_cache(nullptr),
-        left_expr_cache_filled(false),
-        need_expr_cache(true),
-        m_injected_left_expr(nullptr),
-        optimizer(nullptr),
-        was_null(false),
-        abort_on_null(false),
-        in2exists_info(nullptr),
-        pushed_cond_guards(nullptr),
-        upper_item(nullptr) {}
-
-  bool itemize(Parse_context *pc, Item **res) override;
-
-  void cleanup() override;
-  subs_type substype() const override { return IN_SUBS; }
-
-  void reset() override {
-    value = false;
-    null_value = false;
-    was_null = false;
-  }
-  bool select_transformer(THD *thd, Query_block *select) override;
-  bool select_in_like_transformer(THD *thd, Query_block *select,
-                                  Comp_creator *func);
-  bool single_value_transformer(THD *thd, Query_block *select,
-                                Comp_creator *func);
-  bool row_value_transformer(THD *thd, Query_block *select);
-  bool single_value_in_to_exists_transformer(THD *thd, Query_block *select,
-                                             Comp_creator *func);
-  bool row_value_in_to_exists_transformer(THD *thd, Query_block *select);
-  bool subquery_allows_materialization(THD *thd, Query_block *query_block,
-                                       const Query_block *outer);
-  bool walk(Item_processor processor, enum_walk walk, uchar *arg) override;
-  Item *transform(Item_transformer transformer, uchar *arg) override;
-  Item *compile(Item_analyzer analyzer, uchar **arg_p,
-                Item_transformer transformer, uchar *arg_t) override;
-
-  bool exec(THD *thd) override;
-  longlong val_int() override;
-  double val_real() override;
-  String *val_str(String *) override;
-  my_decimal *val_decimal(my_decimal *) override;
-  bool val_bool() override;
-  bool test_limit();
-  void print(const THD *thd, String *str,
-             enum_query_type query_type) const override;
-  bool fix_fields(THD *thd, Item **ref) override;
-  void fix_after_pullout(Query_block *parent_query_block,
-                         Query_block *removed_query_block) override;
-  void update_used_tables() override;
-  bool init_left_expr_cache(THD *thd);
-
-  /**
-     Once the decision to use IN->EXISTS has been taken, performs some last
-     steps of this transformation.
-  */
-  bool finalize_exists_transform(THD *thd, Query_block *select);
-  /**
-     Once the decision to use materialization has been taken, performs some
-     last steps of this transformation.
-  */
-  bool finalize_materialization_transform(THD *thd, JOIN *join);
-  AccessPath *root_access_path() const override;
-  std::optional<ContainedSubquery> get_contained_subquery(
-      const Query_block *outer_query_block) override;
-
-  friend class Item_ref_null_helper;
-  friend class Item_is_not_null_test;
-  friend class Item_in_optimizer;
-  friend class subselect_indexsubquery_engine;
-  friend class subselect_hash_sj_engine;
-
- private:
   bool val_bool_naked();
 };
 
-/// ALL/ANY/SOME subselect.
+/**
+  Class that represents a quantified comparison predicate.
+
+  expression comp-op ANY ( subquery )
+  expression comp-op ALL ( subquery )
+
+  Note that the special cases = ANY (aka IN) and <> ALL (aka NOT IN)
+  are handled by the base class Item_in_subselect.
+*/
 class Item_allany_subselect final : public Item_in_subselect {
  public:
-  chooser_compare_func_creator func_creator;
-  Comp_creator *func;
-  bool all;
-
   Item_allany_subselect(Item *left_expr, chooser_compare_func_creator fc,
                         Query_block *select, bool all);
 
-  // only ALL subquery has upper not
-  subs_type substype() const override { return all ? ALL_SUBS : ANY_SUBS; }
-  bool select_transformer(THD *thd, Query_block *select) override;
+  Subquery_type subquery_type() const override {
+    return m_all ? ALL_SUBQUERY : ANY_SUBQUERY;
+  }
+  bool transformer(THD *thd, Item **transformed) override;
   void print(const THD *thd, String *str,
              enum_query_type query_type) const override;
-};
 
-class SubqueryWithResult {
- public:
-  SubqueryWithResult(Query_expression *u, Query_result_interceptor *res,
-                     Item_subselect *si);
-  /**
-    Cleanup subquery after complete query execution, free all resources.
-  */
-  void cleanup();
-  bool prepare(THD *thd);
-  void fix_length_and_dec(Item_cache **row);
-  /**
-    Execute the subquery
-
-    SYNOPSIS
-      exec()
-
-    DESCRIPTION
-      Execute the subquery. The result of execution is subquery value that is
-      captured by previously set up Query_result-based 'sink'.
-
-    RETURN
-      false - OK
-      true  - Execution error.
-  */
-  bool exec(THD *thd);
-  void print(const THD *thd, String *str, enum_query_type query_type);
-  bool change_query_result(THD *thd, Item_subselect *si,
-                           Query_result_subquery *result);
-  Query_block *single_query_block() const;  // Only if unit is simple.
-
-  enum Item_result type() const { return res_type; }
-  enum_field_types field_type() const { return res_field_type; }
-  bool may_be_null() const { return maybe_null; }
-
-#ifndef NDEBUG
-  /**
-     @returns the internal Item. Defined only in debug builds, because should
-     be used only for debug asserts.
-  */
-  const Item_subselect *get_item() const { return item; }
-#endif
-
- private:
-  Query_result_interceptor *result; /* results storage class */
-  Item_subselect *item;             /* item, that use this subquery */
-  enum Item_result res_type;        /* type of results */
-  enum_field_types res_field_type;  /* column type of the results */
-  /**
-    True if at least one of the columns returned by the subquery may
-    be null, or if a single-row subquery may return zero rows.
-  */
-  bool maybe_null;
-
-  Query_expression *unit; /* corresponding unit structure */
-
-  void set_row(const mem_root_deque<Item *> &item_list, Item_cache **row,
-               bool never_empty);
-
-  friend class subselect_hash_sj_engine;
+  chooser_compare_func_creator m_func_creator;
+  Comp_creator *m_func;
+  bool m_all;
 };
 
 /**
@@ -813,8 +768,8 @@ class subselect_indexsubquery_engine {
   Table_ref *table_ref{nullptr};
   Index_lookup ref;
   join_type type{JT_UNKNOWN};
-  Item *cond;     /* The WHERE condition of subselect */
-  ulonglong hash; /* Hash value calculated by RefIterator, when needed. */
+  Item *m_cond;      ///< The WHERE condition of  the subquery
+  ulonglong m_hash;  ///< Hash value calculated by RefIterator, when needed.
   /*
     The "having" clause. This clause (further referred to as "artificial
     having") was inserted by subquery transformation code. It contains
@@ -825,7 +780,7 @@ class subselect_indexsubquery_engine {
     where we do index lookup on t.key=oe1 but need also to check if there
     was a row such that t.no_key IS NULL.
   */
-  Item *having;
+  Item *m_having;
 
   Item_in_subselect *item; /* item that uses this engine */
 
@@ -836,13 +791,13 @@ class subselect_indexsubquery_engine {
                                  const Index_lookup &ref,
                                  enum join_type join_type,
                                  Item_in_subselect *subs, Item *where,
-                                 Item *having_arg)
+                                 Item *having)
       : table(table),
         table_ref(table_ref),
         ref(ref),
         type(join_type),
-        cond(where),
-        having(having_arg),
+        m_cond(where),
+        m_having(having),
         item(subs) {}
   virtual ~subselect_indexsubquery_engine() = default;
   virtual bool exec(THD *thd);
@@ -887,7 +842,7 @@ class subselect_hash_sj_engine final : public subselect_indexsubquery_engine {
     NEX_TRUE = 2
   };
   enum nulls_exist mat_table_has_nulls;
-  Query_expression *const unit;
+  Query_expression *const m_query_expr;
   unique_ptr_destroy_only<RowIterator> m_iterator;
   AccessPath *m_root_access_path;
 
@@ -896,11 +851,11 @@ class subselect_hash_sj_engine final : public subselect_indexsubquery_engine {
 
  public:
   subselect_hash_sj_engine(Item_in_subselect *in_predicate,
-                           Query_expression *unit_arg)
+                           Query_expression *query_expr)
       : subselect_indexsubquery_engine(nullptr, nullptr, {}, JT_UNKNOWN,
                                        in_predicate, nullptr, nullptr),
         is_materialized(false),
-        unit(unit_arg) {}
+        m_query_expr(query_expr) {}
   ~subselect_hash_sj_engine() override;
 
   bool setup(THD *thd, const mem_root_deque<Item *> &tmp_columns);
@@ -935,7 +890,7 @@ class subselect_hash_sj_engine final : public subselect_indexsubquery_engine {
  */
 Item *remove_in2exists_conds(Item *conds);
 
-/// Returns whether the Item is an IN-subselect.
-bool IsItemInSubSelect(Item *item);
+/// @returns whether the item is a quantified comparison predicate
+bool is_quantified_comp_predicate(Item *item);
 
 #endif /* ITEM_SUBSELECT_INCLUDED */
