@@ -1,16 +1,15 @@
-/* Copyright (c) 2017, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2017, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -44,7 +43,7 @@ Destination_keyring_component::Destination_keyring_component(
     my_service<SERVICE_TYPE(registry_registration)> registrator(
         "registry_registration", srv_registry);
     const char *urn[] = {component_path_.c_str()};
-    bool load_status = dynamic_loader_srv->load(urn, 1);
+    const bool load_status = dynamic_loader_srv->load(urn, 1);
     if (load_status == true) return;
     component_loaded_ = true;
   }
@@ -155,9 +154,9 @@ bool Migrate_keyring::init(int argc, char **argv, char *source_plugin,
   DBUG_TRACE;
 
   std::size_t found = std::string::npos;
-  string equal("=");
-  string so(".so");
-  string dll(".dll");
+  const string equal("=");
+  const string so(".so");
+  const string dll(".dll");
   const string compression_method("zlib,zstd,uncompressed");
 
   if (!source_plugin) {
@@ -487,7 +486,7 @@ bool Migrate_keyring::fetch_and_store_keys() {
          keep track of keys stored in successfully so that they can be
          removed in case of error.
         */
-        Key_info ki(key_id, user_id);
+        const Key_info ki(key_id, user_id);
         m_source_keys.push_back(ki);
       }
     }
