@@ -1,16 +1,15 @@
-/* Copyright (c) 2003, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2003, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,9 +30,11 @@
 #define SQL_BITMAP_INCLUDED
 
 #include <assert.h>
-#include "m_string.h"      // longlong2str
-#include "my_bitmap.h"     // MY_BITMAP
-#include "my_byteorder.h"  // int8store
+
+#include "dig_vec.h"
+#include "my_bitmap.h"              // MY_BITMAP
+#include "my_byteorder.h"           // int8store
+#include "mysql/strings/int2str.h"  // longlong2str
 
 #include "template_utils.h"
 
@@ -110,14 +111,19 @@ class Bitmap {
   bool operator!=(const Bitmap &map2) const { return !(*this == map2); }
   char *print(char *buf) const {
     char *s = buf;
-    const uchar *e = pointer_cast<const uchar *>(&buffer[0]),
-                *b = e + sizeof(buffer) - 1;
-    while (!*b && b > e) b--;
-    if ((*s = _dig_vec_upper[*b >> 4]) != '0') s++;
-    *s++ = _dig_vec_upper[*b & 15];
+    const uchar *e = pointer_cast<const uchar *>(&buffer[0]);
+    const uchar *b = e + sizeof(buffer) - 1;
+    while (*b == 0 && b > e) {
+      b--;
+    }
+    *s = dig_vec_upper[*b >> 4];
+    if (*s != '0') {
+      s++;
+    }
+    *s++ = dig_vec_upper[*b & 15];
     while (--b >= e) {
-      *s++ = _dig_vec_upper[*b >> 4];
-      *s++ = _dig_vec_upper[*b & 15];
+      *s++ = dig_vec_upper[*b >> 4];
+      *s++ = dig_vec_upper[*b & 15];
     }
     *s = 0;
     return buf;
