@@ -1,17 +1,16 @@
 /*
-   Copyright (c) 2000, 2024, Oracle and/or its affiliates.
+   Copyright (c) 2000, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,24 +38,24 @@
 #include <limits>
 
 #include "libbinlogevents/include/load_data_events.h"
-#include "m_ctype.h"
-#include "m_string.h"
 #include "my_base.h"
 #include "my_bitmap.h"
 #include "my_dbug.h"
 #include "my_dir.h"
 #include "my_inttypes.h"
 #include "my_io.h"
-#include "my_loglevel.h"
 #include "my_macros.h"
 #include "my_sys.h"
 #include "my_thread_local.h"
 #include "mysql/components/services/log_builtins.h"
+#include "mysql/my_loglevel.h"
 #include "mysql/psi/mysql_file.h"
 #include "mysql/service_mysql_alloc.h"
+#include "mysql/strings/m_ctype.h"
 #include "mysql/thread_type.h"
 #include "mysql_com.h"
 #include "mysqld_error.h"
+#include "nulls.h"
 #include "sql/auth/auth_acls.h"
 #include "sql/auth/auth_common.h"
 #include "sql/binlog.h"
@@ -91,6 +90,8 @@
 #include "sql/transaction_info.h"
 #include "sql/trigger_def.h"
 #include "sql_string.h"
+#include "string_with_len.h"
+#include "strxnmov.h"
 #include "thr_lock.h"
 
 class READ_INFO;
@@ -622,7 +623,8 @@ bool Sql_cmd_load_table::execute_inner(THD *thd,
         read_info.end_io_cache();
         /* If the file was not empty, wrote_create_file is true */
         if (lf_info.logged_data_file) {
-          int errcode = query_error_code(thd, killed_status == THD::NOT_KILLED);
+          const int errcode =
+              query_error_code(thd, killed_status == THD::NOT_KILLED);
 
           /* since there is already an error, the possible error of
              writing binary log will be ignored */
@@ -666,7 +668,8 @@ bool Sql_cmd_load_table::execute_inner(THD *thd,
       */
       read_info.end_io_cache();
       if (lf_info.logged_data_file) {
-        int errcode = query_error_code(thd, killed_status == THD::NOT_KILLED);
+        const int errcode =
+            query_error_code(thd, killed_status == THD::NOT_KILLED);
         error = write_execute_load_query_log_event(
             thd, table_list->db, table_list->table_name, is_concurrent,
             handle_duplicates, transactional_table, errcode);
@@ -796,7 +799,8 @@ bool Sql_cmd_load_table::read_fixed_length(THD *thd, COPY_INFO &info,
       break;
     }
 
-    Autoinc_field_has_explicit_non_null_value_reset_guard after_each_row(table);
+    const Autoinc_field_has_explicit_non_null_value_reset_guard after_each_row(
+        table);
 
     for (Item *item : m_opt_fields_or_vars) {
       // Skip hidden generated columns.
@@ -952,7 +956,8 @@ bool Sql_cmd_load_table::read_sep_field(THD *thd, COPY_INFO &info,
       break;
     }
 
-    Autoinc_field_has_explicit_non_null_value_reset_guard after_each_row(table);
+    const Autoinc_field_has_explicit_non_null_value_reset_guard after_each_row(
+        table);
 
     auto it = m_opt_fields_or_vars.begin();
     for (; it != m_opt_fields_or_vars.end(); ++it) {
@@ -1180,7 +1185,8 @@ bool Sql_cmd_load_table::read_xml_field(THD *thd, COPY_INFO &info,
       break;
     }
 
-    Autoinc_field_has_explicit_non_null_value_reset_guard after_each_row(table);
+    const Autoinc_field_has_explicit_non_null_value_reset_guard after_each_row(
+        table);
 
     auto it = m_opt_fields_or_vars.begin();
     Item *item = nullptr;
@@ -1431,7 +1437,7 @@ READ_INFO::~READ_INFO() {
   do {                                                  \
     len = my_mbcharlen((cs), (chr));                    \
     if (len == 0 && my_mbmaxlenlen((cs)) == 2) {        \
-      int chr1 = GET;                                   \
+      const int chr1 = GET;                             \
       if (chr1 != my_b_EOF) {                           \
         len = my_mbcharlen_2((cs), (chr), chr1);        \
         /* Character is gb18030 or invalid (len = 0) */ \
@@ -2120,7 +2126,7 @@ found_eof:
 bool Sql_cmd_load_table::execute(THD *thd) {
   LEX *const lex = thd->lex;
 
-  uint privilege =
+  const uint privilege =
       (lex->duplicates == DUP_REPLACE ? INSERT_ACL | DELETE_ACL : INSERT_ACL) |
       (m_is_local_file ? 0 : FILE_ACL);
 
@@ -2142,10 +2148,10 @@ bool Sql_cmd_load_table::execute(THD *thd) {
   else if (thd->is_strict_mode())
     thd->push_internal_handler(&strict_handler);
 
-  lex->set_using_hypergraph_optimizer(
-      thd->optimizer_switch_flag(OPTIMIZER_SWITCH_HYPERGRAPH_OPTIMIZER));
+  lex->using_hypergraph_optimizer =
+      thd->optimizer_switch_flag(OPTIMIZER_SWITCH_HYPERGRAPH_OPTIMIZER);
 
-  bool res = execute_inner(thd, lex->duplicates);
+  const bool res = execute_inner(thd, lex->duplicates);
 
   /* Pop ignore / strict error handler */
   if (thd->lex->is_ignore() || thd->is_strict_mode())
