@@ -1,17 +1,16 @@
 /*
-   Copyright (c) 2003, 2024, Oracle and/or its affiliates.
+   Copyright (c) 2003, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,6 +29,7 @@
 
 #define JAM_FILE_ID 307
 
+
 /**
  * DLHashTable2 is a DLHashTable variant meant for cases where different
  * DLHashTable instances share a common pool (based on a union U).
@@ -40,11 +40,10 @@
 template <class P, class T = typename P::Type>
 class DLHashTable2 {
   typedef typename P::Type U;
-
- public:
-  DLHashTable2(P &thePool);
+public:
+  DLHashTable2(P & thePool);
   ~DLHashTable2();
-
+  
   /**
    * Set the no of bucket in the hashtable
    *
@@ -64,13 +63,13 @@ class DLHashTable2 {
    * Add an object to the hashtable
    */
   void add(Ptr<T> &);
-
+  
   /**
-   * Find element key in hashtable update Ptr (i & p)
+   * Find element key in hashtable update Ptr (i & p) 
    *   (using key.equal(...))
    * @return true if found and false otherwise
    */
-  bool find(Ptr<T> &, const T &key) const;
+  bool find(Ptr<T> &, const T & key) const;
 
   /**
    * Update i & p value according to <b>i</b>
@@ -85,13 +84,13 @@ class DLHashTable2 {
   /**
    * Get P value for i
    */
-  T *getPtr(Uint32 i) const;
+  T * getPtr(Uint32 i) const;
 
   /**
    * Remove element (and set Ptr to removed element)
    * Note does not return to pool
    */
-  void remove(Ptr<T> &, const T &key);
+  void remove(Ptr<T> &, const T & key);
 
   /**
    * Remove element
@@ -109,12 +108,12 @@ class DLHashTable2 {
    * Remove all elements, but dont return them to pool
    */
   void removeAll();
-
+  
   /**
    * Remove element (and set Ptr to removed element)
    * And return element to pool
    */
-  void release(Ptr<T> &, const T &key);
+  void release(Ptr<T> &, const T & key);
 
   /**
    * Remove element and return to pool
@@ -125,31 +124,31 @@ class DLHashTable2 {
    * Remove element and return to pool
    */
   void release(Ptr<T> &);
-
+  
   class Iterator {
-   public:
+  public:
     Ptr<T> curr;
     Uint32 bucket;
-    inline bool isNull() const { return curr.isNull(); }
+    inline bool isNull() const { return curr.isNull();}
     inline void setNull() { curr.setNull(); }
   };
 
   /**
    * Sets curr.p according to curr.i
    */
-  void getPtr(Iterator &iter) const;
+  void getPtr(Iterator & iter) const ;
 
   /**
    * First element in bucket
    */
-  bool first(Iterator &iter) const;
-
+  bool first(Iterator & iter) const;
+  
   /**
    * Next Element
    *
    * param iter - A "fully set" iterator
    */
-  bool next(Iterator &iter) const;
+  bool next(Iterator & iter) const;
 
   /**
    * Get next element starting from bucket
@@ -157,67 +156,76 @@ class DLHashTable2 {
    * @param bucket - Which bucket to start from
    * @param iter - An "uninitialized" iterator
    */
-  bool next(Uint32 bucket, Iterator &iter) const;
+  bool next(Uint32 bucket, Iterator & iter) const;
 
-  inline bool isEmpty() const {
-    Iterator iter;
-    return !first(iter);
-  }
-
- private:
+  inline bool isEmpty() const { Iterator iter; return ! first(iter); }
+  
+private:
   Uint32 mask;
-  Uint32 *hashValues;
-  P &thePool;
+  Uint32 * hashValues;
+  P & thePool;
 };
 
-template <class P, class T>
-inline DLHashTable2<P, T>::DLHashTable2(P &_pool) : thePool(_pool) {
+template<class P, class T>
+inline
+DLHashTable2<P, T>::DLHashTable2(P & _pool)
+  : thePool(_pool)
+{
   mask = 0;
   hashValues = 0;
 }
 
-template <class P, class T>
-inline DLHashTable2<P, T>::~DLHashTable2() {
-  if (hashValues != 0) delete[] hashValues;
+template<class P, class T>
+inline
+DLHashTable2<P, T>::~DLHashTable2(){
+  if(hashValues != 0)
+    delete [] hashValues;
 }
 
-template <class P, class T>
-inline bool DLHashTable2<P, T>::setSize(Uint32 size) {
+template<class P, class T>
+inline
+bool
+DLHashTable2<P, T>::setSize(Uint32 size){
   Uint32 i = 1;
-  while (i < size) i *= 2;
+  while(i < size) i *= 2;
 
-  if (hashValues != NULL) {
+  if (hashValues != NULL)
+  {
     /*
-      If setSize() is called twice with different size values then this is
+      If setSize() is called twice with different size values then this is 
       most likely a bug.
     */
-    assert(mask == i - 1);
+    assert(mask == i-1); 
     // Return true if size already set to 'size', false otherwise.
-    return mask == i - 1;
+    return mask == i-1;
   }
-
+  
   mask = (i - 1);
   hashValues = new Uint32[i];
-  for (Uint32 j = 0; j < i; j++) hashValues[j] = RNIL;
-
+  for(Uint32 j = 0; j<i; j++)
+    hashValues[j] = RNIL;
+  
   return true;
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::add(Ptr<T> &obj) {
+template<class P, class T>
+inline
+void
+DLHashTable2<P, T>::add(Ptr<T> & obj){
   const Uint32 hv = obj.p->hashValue() & mask;
-  const Uint32 i = hashValues[hv];
-
-  if (i == RNIL) {
+  const Uint32 i  = hashValues[hv];
+  
+  if(i == RNIL){
     hashValues[hv] = obj.i;
     obj.p->nextHash = RNIL;
     obj.p->prevHash = RNIL;
   } else {
-    T *tmp = (T *)thePool.getPtr(i);  // cast
+    
+    T * tmp = (T*)thePool.getPtr(i);    // cast
     tmp->prevHash = obj.i;
     obj.p->nextHash = i;
     obj.p->prevHash = RNIL;
-
+    
     hashValues[hv] = obj.i;
   }
 }
@@ -225,14 +233,16 @@ inline void DLHashTable2<P, T>::add(Ptr<T> &obj) {
 /**
  * First element
  */
-template <class P, class T>
-inline bool DLHashTable2<P, T>::first(Iterator &iter) const {
+template<class P, class T>
+inline
+bool
+DLHashTable2<P, T>::first(Iterator & iter) const {
   Uint32 i = 0;
-  while (i <= mask && hashValues[i] == RNIL) i++;
-  if (i <= mask) {
+  while(i <= mask && hashValues[i] == RNIL) i++;
+  if(i <= mask){
     iter.bucket = i;
     iter.curr.i = hashValues[i];
-    iter.curr.p = (T *)thePool.getPtr(iter.curr.i);  // cast
+    iter.curr.p = (T*)thePool.getPtr(iter.curr.i);      // cast
     return true;
   } else {
     iter.curr.i = RNIL;
@@ -240,50 +250,54 @@ inline bool DLHashTable2<P, T>::first(Iterator &iter) const {
   return false;
 }
 
-template <class P, class T>
-inline bool DLHashTable2<P, T>::next(Iterator &iter) const {
-  if (iter.curr.p->nextHash == RNIL) {
+template<class P, class T>
+inline
+bool
+DLHashTable2<P, T>::next(Iterator & iter) const {
+  if(iter.curr.p->nextHash == RNIL){
     Uint32 i = iter.bucket + 1;
-    while (i <= mask && hashValues[i] == RNIL) i++;
-    if (i <= mask) {
+    while(i <= mask && hashValues[i] == RNIL) i++;
+    if(i <= mask){
       iter.bucket = i;
       iter.curr.i = hashValues[i];
-      iter.curr.p = (T *)thePool.getPtr(iter.curr.i);  // cast
+      iter.curr.p = (T*)thePool.getPtr(iter.curr.i);    // cast
       return true;
     } else {
       iter.curr.i = RNIL;
       return false;
     }
   }
-
+  
   iter.curr.i = iter.curr.p->nextHash;
-  iter.curr.p = (T *)thePool.getPtr(iter.curr.i);  // cast
+  iter.curr.p = (T*)thePool.getPtr(iter.curr.i);        // cast
   return true;
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::remove(Ptr<T> &ptr, const T &key) {
-  const Uint32 hv = key.hashValue() & mask;
-
+template<class P, class T>
+inline
+void
+DLHashTable2<P, T>::remove(Ptr<T> & ptr, const T & key){
+  const Uint32 hv = key.hashValue() & mask;  
+  
   Uint32 i;
-  T *p;
+  T * p;
   Ptr<T> prev;
   prev.i = RNIL;
 
   i = hashValues[hv];
-  while (i != RNIL) {
-    p = (T *)thePool.getPtr(i);  // cast
-    if (key.equal(*p)) {
+  while(i != RNIL){
+    p = (T*)thePool.getPtr(i);  // cast
+    if(key.equal(* p)){
       const Uint32 next = p->nextHash;
-      if (prev.i == RNIL) {
-        hashValues[hv] = next;
+      if(prev.i == RNIL){
+	hashValues[hv] = next;
       } else {
-        prev.p->nextHash = next;
+	prev.p->nextHash = next;
       }
-
-      if (next != RNIL) {
-        T *nextP = (T *)thePool.getPtr(next);  // cast
-        nextP->prevHash = prev.i;
+      
+      if(next != RNIL){
+	T * nextP = (T*)thePool.getPtr(next);   // cast
+	nextP->prevHash = prev.i;
       }
 
       ptr.i = i;
@@ -297,35 +311,37 @@ inline void DLHashTable2<P, T>::remove(Ptr<T> &ptr, const T &key) {
   ptr.i = RNIL;
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::release(Ptr<T> &ptr, const T &key) {
-  const Uint32 hv = key.hashValue() & mask;
-
+template<class P, class T>
+inline
+void
+DLHashTable2<P, T>::release(Ptr<T> & ptr, const T & key){
+  const Uint32 hv = key.hashValue() & mask;  
+  
   Uint32 i;
-  T *p;
+  T * p;
   Ptr<T> prev;
   prev.i = RNIL;
 
   i = hashValues[hv];
-  while (i != RNIL) {
-    p = (T *)thePool.getPtr(i);  // cast
-    if (key.equal(*p)) {
+  while(i != RNIL){
+    p = (T*)thePool.getPtr(i);  // cast
+    if(key.equal(* p)){
       const Uint32 next = p->nextHash;
-      if (prev.i == RNIL) {
-        hashValues[hv] = next;
+      if(prev.i == RNIL){
+	hashValues[hv] = next;
       } else {
-        prev.p->nextHash = next;
+	prev.p->nextHash = next;
       }
-
-      if (next != RNIL) {
-        T *nextP = (T *)thePool.getPtr(next);  // cast
-        nextP->prevHash = prev.i;
+      
+      if(next != RNIL){
+	T * nextP = (T*)thePool.getPtr(next);   // cast
+	nextP->prevHash = prev.i;
       }
 
       p->~T();  // dtor
       thePool.release(i);
       ptr.i = i;
-      ptr.p = p;  // invalid
+      ptr.p = p;        // invalid
       return;
     }
     prev.p = p;
@@ -335,136 +351,167 @@ inline void DLHashTable2<P, T>::release(Ptr<T> &ptr, const T &key) {
   ptr.i = RNIL;
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::remove(Uint32 i) {
+template<class P, class T>
+inline
+void
+DLHashTable2<P, T>::remove(Uint32 i){
   Ptr<T> tmp;
   tmp.i = i;
-  tmp.p = (T *)thePool.getPtr(i);  // cast
+  tmp.p = (T*)thePool.getPtr(i);        // cast
   remove(tmp);
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::release(Uint32 i) {
+template<class P, class T>
+inline
+void
+DLHashTable2<P, T>::release(Uint32 i){
   Ptr<T> tmp;
   tmp.i = i;
-  tmp.p = (T *)thePool.getPtr(i);  // cast
+  tmp.p = (T*)thePool.getPtr(i);        // cast
   release(tmp);
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::remove(Ptr<T> &ptr) {
+template<class P, class T>
+inline
+void 
+DLHashTable2<P, T>::remove(Ptr<T> & ptr){
   const Uint32 next = ptr.p->nextHash;
   const Uint32 prev = ptr.p->prevHash;
 
-  if (prev != RNIL) {
-    T *prevP = (T *)thePool.getPtr(prev);  // cast
+  if(prev != RNIL){
+    T * prevP = (T*)thePool.getPtr(prev);       // cast
     prevP->nextHash = next;
   } else {
-    const Uint32 hv = ptr.p->hashValue() & mask;
-    if (hashValues[hv] == ptr.i) {
+    const Uint32 hv = ptr.p->hashValue() & mask;  
+    if (hashValues[hv] == ptr.i)
+    {
       hashValues[hv] = next;
-    } else {
+    }
+    else
+    {
       // Will add assert in 5.1
     }
   }
-
-  if (next != RNIL) {
-    T *nextP = (T *)thePool.getPtr(next);  // cast
+  
+  if(next != RNIL){
+    T * nextP = (T*)thePool.getPtr(next);       // cast
     nextP->prevHash = prev;
   }
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::release(Ptr<T> &ptr) {
+template<class P, class T>
+inline
+void 
+DLHashTable2<P, T>::release(Ptr<T> & ptr){
   const Uint32 next = ptr.p->nextHash;
   const Uint32 prev = ptr.p->prevHash;
 
-  if (prev != RNIL) {
-    T *prevP = (T *)thePool.getPtr(prev);  // cast
+  if(prev != RNIL){
+    T * prevP = (T*)thePool.getPtr(prev);       // cast
     prevP->nextHash = next;
   } else {
-    const Uint32 hv = ptr.p->hashValue() & mask;
-    if (hashValues[hv] == ptr.i) {
+    const Uint32 hv = ptr.p->hashValue() & mask;  
+    if (hashValues[hv] == ptr.i)
+    {
       hashValues[hv] = next;
-    } else {
+    }
+    else
+    {
       // Will add assert in 5.1
     }
   }
-
-  if (next != RNIL) {
-    T *nextP = (T *)thePool.getPtr(next);  // cast
+  
+  if(next != RNIL){
+    T * nextP = (T*)thePool.getPtr(next);       // cast
     nextP->prevHash = prev;
   }
-
+  
   thePool.release(ptr.i);
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::removeAll() {
-  for (Uint32 i = 0; i <= mask; i++) hashValues[i] = RNIL;
+template<class P, class T>
+inline
+void 
+DLHashTable2<P, T>::removeAll(){
+  for(Uint32 i = 0; i<=mask; i++)
+    hashValues[i] = RNIL;
 }
 
-template <class P, class T>
-inline bool DLHashTable2<P, T>::next(Uint32 bucket, Iterator &iter) const {
-  while (bucket <= mask && hashValues[bucket] == RNIL) bucket++;
-
+template<class P, class T>
+inline
+bool
+DLHashTable2<P, T>::next(Uint32 bucket, Iterator & iter) const {
+  while (bucket <= mask && hashValues[bucket] == RNIL) 
+    bucket++; 
+  
   if (bucket > mask) {
     iter.bucket = bucket;
     iter.curr.i = RNIL;
     return false;
   }
-
+  
   iter.bucket = bucket;
   iter.curr.i = hashValues[bucket];
-  iter.curr.p = (T *)thePool.getPtr(iter.curr.i);  // cast
+  iter.curr.p = (T*)thePool.getPtr(iter.curr.i);        // cast
   return true;
 }
 
-template <class P, class T>
-inline bool DLHashTable2<P, T>::seize(Ptr<T> &ptr) {
+template<class P, class T>
+inline
+bool
+DLHashTable2<P, T>::seize(Ptr<T> & ptr){
   Ptr<U> ptr2;
-  if (!thePool.seize(ptr2)) return false;
+  if (!thePool.seize(ptr2))
+    return false;
 
   ptr.i = ptr2.i;
-  ptr.p = (T *)ptr2.p;  // cast
+  ptr.p = (T*)ptr2.p;   // cast
   require(ptr.p != NULL);
 
   ptr.p->nextHash = RNIL;
   ptr.p->prevHash = RNIL;
-  new (ptr.p) T;  // ctor
+  new (ptr.p) T;      // ctor
   return true;
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::getPtr(Ptr<T> &ptr, Uint32 i) const {
+template<class P, class T>
+inline
+void
+DLHashTable2<P, T>::getPtr(Ptr<T> & ptr, Uint32 i) const {
   ptr.i = i;
-  ptr.p = (T *)thePool.getPtr(i);  // cast
+  ptr.p = (T*)thePool.getPtr(i);        // cast
 }
 
-template <class P, class T>
-inline void DLHashTable2<P, T>::getPtr(Ptr<T> &ptr) const {
+template<class P, class T>
+inline
+void
+DLHashTable2<P, T>::getPtr(Ptr<T> & ptr) const {
   Ptr<U> ptr2;
   thePool.getPtr(ptr2);
   ptr.i = ptr2.i;
-  ptr.p = (T *)ptr2.p;  // cast
+  ptr.p = (T*)ptr2.p;   // cast
 }
 
-template <class P, class T>
-inline T *DLHashTable2<P, T>::getPtr(Uint32 i) const {
-  return (T *)thePool.getPtr(i);  // cast
+template<class P, class T>
+inline
+T * 
+DLHashTable2<P, T>::getPtr(Uint32 i) const {
+  return (T*)thePool.getPtr(i); // cast
 }
 
-template <class P, class T>
-inline bool DLHashTable2<P, T>::find(Ptr<T> &ptr, const T &key) const {
-  const Uint32 hv = key.hashValue() & mask;
-
+template<class P, class T>
+inline
+bool
+DLHashTable2<P, T>::find(Ptr<T> & ptr, const T & key) const {
+  const Uint32 hv = key.hashValue() & mask;  
+  
   Uint32 i;
-  T *p;
+  T * p;
 
   i = hashValues[hv];
-  while (i != RNIL) {
-    p = (T *)thePool.getPtr(i);  // cast
-    if (key.equal(*p)) {
+  while(i != RNIL){
+    p = (T*)thePool.getPtr(i);  // cast
+    if(key.equal(* p)){
       ptr.i = i;
       ptr.p = p;
       return true;
