@@ -1,4 +1,4 @@
-/* Copyright (c) 2016, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2016, 2023, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License, version 2.0, as published by the
@@ -118,6 +118,36 @@ struct MemoryMonitor {
   static std::atomic<size_t> mmap;
 };
 
+/* Thin abstraction which enables logging of how much resources have been
+ * consumed at the per-table level. Each temptable::Table will be composed
+ * of this type so that the temptable::Allocator through its policies can
+ * monitor its memory consumption and act appropriately when threshold
+ * is reached.
+ **/
+class TableResourceMonitor {
+ public:
+  TableResourceMonitor(size_t threshold)
+      : m_threshold(threshold), m_total_bytes(0) {}
+
+  size_t increase(size_t bytes) {
+    assert(m_total_bytes <=
+           std::numeric_limits<decltype(bytes)>::max() - bytes);
+    m_total_bytes += bytes;
+    return m_total_bytes;
+  }
+  size_t decrease(size_t bytes) {
+    assert(m_total_bytes >= bytes);
+    m_total_bytes -= bytes;
+    return m_total_bytes;
+  }
+  size_t threshold() { return m_threshold; }
+  size_t consumption() { return m_total_bytes; }
+
+ private:
+  size_t m_threshold;
+  size_t m_total_bytes;
+};
+
 /* Allocation scheme, a type which controls allocation patterns in TempTable
  * allocator.
  *
@@ -170,12 +200,14 @@ struct Allocation_scheme {
 /* Concrete implementation of Block_source_policy, a type which controls where
  * TempTable allocator is going to be allocating next Block of memory from.
  *
- * In particular, this policy will make TempTable allocator to:
+ * In particular, this policy will make TempTable allocator:
  *  1. Use RAM as long as temptable_max_ram threshold is not reached.
  *  2. Start using MMAP when temptable_max_ram threshold is reached.
  *  3. Go back using RAM as soon as RAM consumption drops below the
- *     temptable_max_ram threshold and there is enough space to accomodate the
+ *     temptable_max_ram threshold and there is enough space to accommodate the
  *     new block given the size.
+ *  4. Not take into account per-table memory limits defined through
+ *     tmp_table_size SYSVAR.
  * */
 struct Prefer_RAM_over_MMAP_policy {
   static Source block_source(uint32_t block_size) {
@@ -339,7 +371,7 @@ class Allocator {
   };
 
   /** Constructor. */
-  explicit Allocator(Block *shared_block);
+  Allocator(Block *shared_block, TableResourceMonitor &table_resource_monitor);
 
   /** Constructor from allocator of another type. The state is copied into the
    * new object. */
@@ -425,27 +457,37 @@ class Allocator {
    * memory of this shared block.
    */
   Block *m_shared_block;
+  /** Table resource monitor control mechanism that limits the amount of
+   *  resources that can be consumed at the per-table level.
+   */
+  TableResourceMonitor &m_table_resource_monitor;
 };
 
 /* Implementation of inlined methods. */
 
 template <class T, class AllocationScheme>
-inline Allocator<T, AllocationScheme>::Allocator(Block *shared_block)
+inline Allocator<T, AllocationScheme>::Allocator(
+    Block *shared_block, TableResourceMonitor &table_resource_monitor)
     : m_state(std::make_shared<AllocatorState>()),
-      m_shared_block(shared_block) {}
+      m_shared_block(shared_block),
+      m_table_resource_monitor(table_resource_monitor) {}
 
 template <class T, class AllocationScheme>
 template <class U>
 inline Allocator<T, AllocationScheme>::Allocator(const Allocator<U> &other)
-    : m_state(other.m_state), m_shared_block(other.m_shared_block) {}
+    : m_state(other.m_state),
+      m_shared_block(other.m_shared_block),
+      m_table_resource_monitor(other.m_table_resource_monitor) {}
 
 template <class T, class AllocationScheme>
 template <class U>
 inline Allocator<T, AllocationScheme>::Allocator(Allocator<U> &&other) noexcept
-    : m_state(std::move(other.m_state)), m_shared_block(other.m_shared_block) {}
+    : m_state(std::move(other.m_state)),
+      m_shared_block(other.m_shared_block),
+      m_table_resource_monitor(other.m_table_resource_monitor) {}
 
 template <class T, class AllocationScheme>
-inline Allocator<T, AllocationScheme>::~Allocator() {}
+inline Allocator<T, AllocationScheme>::~Allocator() = default;
 
 template <class T, class AllocationScheme>
 template <class U>
@@ -496,6 +538,24 @@ inline T *Allocator<T, AllocationScheme>::allocate(size_t n_elements) {
     block = &m_state->current_block;
   }
 
+  /* temptable::Table is allowed to fit no more data than the given threshold
+   * controlled through TableResourceMonitor abstraction. TableResourceMonitor
+   * is a simple abstraction which is in its part an alias for tmp_table_size, a
+   * system variable that end MySQL users will be using to control this
+   * threshold.
+   *
+   * Updating the tmp_table_size threshold can only be done through the separate
+   * SET statement which implies that the tmp_table_size threshold cannot be
+   * updated during the duration of some query which is running within the same
+   * session. Separate sessions can still of course change this value to their
+   * liking.
+   */
+  if (m_table_resource_monitor.consumption() + n_bytes_requested >
+      m_table_resource_monitor.threshold()) {
+    throw Result::RECORD_FILE_FULL;
+  }
+  m_table_resource_monitor.increase(n_bytes_requested);
+
   T *chunk_data =
       reinterpret_cast<T *>(block->allocate(n_bytes_requested).data());
   assert(reinterpret_cast<uintptr_t>(chunk_data) % alignof(T) == 0);
@@ -534,6 +594,7 @@ inline void Allocator<T, AllocationScheme>::deallocate(T *chunk_data,
       --m_state->number_of_blocks;
     }
   }
+  m_table_resource_monitor.decrease(n_bytes_requested);
 }
 
 template <class T, class AllocationScheme>
